# Text-related datasets

This [datasets](https://github.com/bpiwowar/datasets) plugin covers text-related datasets:

- Information Retrieval
- Natural Language Processing tasks

The list of available datasets and usage instruction can be found in the [documentation](http://bpiwowar.github.io/datamaestro_text/).

## List of available datasets

### Documents

- Aquaint (TREC)
- TIPSTER (TREC)
- WikiText-2 and WikiText-103

### Word embeddings

- [Glove](http://nlp.stanford.edu/projects/glove/) `edu.stanford.glove.XXXX`

### Sentiment analysis

- [IMDB]() `edu.stanford.aclimdb`

### Information Retrieval

#### TREC

- TREC-1 to TREC-8
- Robust 2004 and 2005